window.Gleam.initSearch([{"doc":"vleam","title":"vleam","content":"### **THIS IS EXPERIMENTAL SOFTWARE**.\n\nIt can be used in production, but may cause headaches to the developer.\n\n&lt;p align=&quot;center&quot;&gt;\n  &lt;img height=&quot;200&quot; src=&quot;logo.png&quot;&gt;\n&lt;/p&gt;\n\n# Vleam\n\n**Incrementally incorporate Gleam in Vue projects to enjoy an enjoyable language**\n\nVleam (Vue + Gleam) is a set of tools allowing developers to _incrementally_\nincorporate the Gleam programming language into their Vue projects.\n\nSimilarly to how Typescript helped with the large codebases of 2016, Gleam can\nhelp with the large codebases of today. Most apps aren&#39;t going to be rewritten.\nNo reason why they shouldn&#39;t benefit from a better language, especially when\nintroduced slowly and incrementally, and particularly if it means less Typescript.\n\nTo learn more about how Gleam can do those things, visit [Gleam&#39;s language tour](https://tour.gleam.run)\nif you haven&#39;t already.\n\nVleam consists of three parts:\n\n1. A Vite plugin that:\n\n- Allows the use of `&lt;script lang=&quot;gleam&quot;&gt;` in Vue SFCs\n- Allows importing `.gleam` files in Javascript/Typescript.\n\n2. A set of bindings to Vue&#39;s APIs.\n\n3. An LSP that proxies messages between Gleam&#39;s LSP for functionality in SFCs.\n   Plugins are availble for Neovim and VSCode.\n\n## Prerequisites\n\n1. A Vue 3 project using Vite\n2. Working installation of [Gleam&#39;s CLI](https://gleam.run/getting-started/installing/)\n\n## Setup\n\nThe following uses `pnpm` but `yarn` or `npm` should work as well.\n\nFirst, setup a Gleam project in your Vue project&#39;s root by using `gleam new` or\nby manually creating a `gleam.toml` file. Make sure you set `target = &quot;javascript&quot;`.\n\nThen, install Vleam:\n\n```shell\npnpm add -D vleam\ngleam add vleam\n```\n\nAnd add it as the **first** plugin in `vite.config.ts`:\n\n```ts\nimport { vitePluginVueVleam } from &quot;vleam&quot;;\n\nexport default defineConfig({\n  // ... rest of your config ...\n  plugins: [\n    // Vleam first\n    vitePluginVueVleam(),\n    // Then the rest\n    vue(),\n    // ... rest of your plugins ...\n  ],\n});\n```\n\nAdd `src/vleam_generated` to `.gitignore`.\n\nFor Neovim support, install [vleam.nvim](https://github.com/vleam/vleam.nvim).\n\nFor VSCode support, install the [vleam plugin](https://github.com/vleam/vscode-vleam).\n\nIf you&#39;d like to get type information for Gleam code imported in Typescript,\ninstall `ts-gleam` as well:\n\n```shell\npnpm add -D ts-gleam\n```\n\nand make sure `gleam.toml` has Typescript declarations configured:\n\n```toml\n[javascript]\ntypescript_declarations = true\n```\n\nThat&#39;s it!\n\n### Usage\n\nTo use Gleam code in TS or JS files, simply import as usual:\n\n```ts\n// this imports the function `new_todo` from `models.gleam`\nimport { new_todo } from &quot;../vleam_todo/models.gleam&quot;;\n```\n\nIn Vue SFCs, you can use Gleam like so:\n\n```gleam\n// this code is inside &lt;script lang=&quot;gleam&quot;&gt; &lt;/script&gt;\nimport gleam/option.{Some}\nimport vleam/vue.{type Component, Prop, define_component, setup, with_1_prop}\n\n// THIS FUNCTION MUST EXIST\npub fn default_export() -&gt; Component {\n  define_component([], [], False)\n  |&gt; with_1_prop(#(Prop(&quot;initialCount&quot;, Some(0))))\n  // Props are handed as Computed to stay reactive\n  |&gt; setup(fn(props: #(Computed(Int)), _, _) {\n    let initial_count = props.0\n\n    let counter =\n      initial_count\n      |&gt; vue.computed_value\n      |&gt; vue.ref\n\n    let increment = fn() -&gt; Int {\n      let current_count =\n        counter\n        |&gt; vue.ref_value\n\n      counter\n      |&gt; vue.ref_set(current_count)\n\n      current_count\n    }\n\n    // returning an Error will cause `setup` to throw it\n    Ok(#(\n      #(&quot;counter&quot;, counter),\n      #(&quot;increment&quot;, increment),\n    ))\n  })\n}\n```\n\nNote that a Gleam script block inside a Vue SFC, without exception, MUST declare\na public `default_export` function that returns a `Component`. The Vite plugin\nassumes it exists and the build will fail without it.\n\nFor more information on Vue bindings in Gleam, see the reference at Hexdocs:\n\nhttps://hexdocs.pm/vleam\n\n### Automatic Unwrapping\n\nVleam takes inspiration from Gleam in its magic avoidance, only introducing it\nwhen the alternative is too poor of a developer experience. The only such case\nat the moment is null handling in templates.\n\nGleam doesn&#39;t have null. Therefore, every time a setup function returns an `Option`,\nit will be unwrapped to the contained value if `Some`, or to `null` if `None`.\n\nThis unwrapping happens for:\n\n1. A literal `Option`\n2. Functions returning an `Option`, recursively\n3. Records&#39; fields which are an `Option`, non-recursively\n\nRecursing records for the unwrapping of fields in arbitrary depths is not supported\ndue to performance considerations.\n\nALL THREE AFFECT ONLY VALUES RETURNED BY `setup`. If you have acquired an `Option`\nthrough other means (e.g a global vue value or an event), it will not be unwrapped.\nThis is an unfortunate limitation of Vue.\n\nNullable values going from the template into Gleam code (via a function call) will\nneed to be converted into an `Option`. This can be done ergonomically with\n`globalProperties`:\n\n```ts\n// define once in main.ts\nimport {\n  Some,\n  None,\n} from &quot;/build/dev/javascript/gleam_stdlib/gleam/option.mjs&quot;;\n\napp.config.globalProperties.toOption = (nullable) =&gt;\n  nullable == null ? new None() : new Some(nullable);\n```\n\nThen, use in templates:\n\n```vue\n&lt;button @click=&quot;signup(email, password, toOption(phoneNumber))&quot;&gt;Sign Up&lt;/button&gt;\n```\n\n### Tips\n\n- Use absolute paths with Gleam `@external`. Vite will resolve them relative\n  to its root:\n\n```gleam\n// Easy\n@external(javascript, &quot;/src/composables/useTodoInputEvent&quot;, &quot;useTodoInputEvent&quot;)\nfn use_todo_input_event(event: InputEvent) -&gt; Result(Todo, TodoError)\n\n// Pain\n@external(javascript, &quot;../../../../composables/useTodoInputEvent&quot;, &quot;useTodoInputEvent&quot;)\nfn use_todo_input_event(event: InputEvent) -&gt; Result(Todo, TodoError)\n```\n\n- If the LSP glitches `&lt;script lang=&quot;gleam&quot;&gt;`, resave the file. Also try\n  formatting the gleam code then save.\n\n- If something doesn&#39;t work and you&#39;re not sure why, check the browser console\n  for errors, and scroll up the terminal to see if any error slipped by.\n\n### Limitations\n\n#### HMR\n\nDue to the way HMR works, `instanceof` may break if a new version of the class\nis reloaded after objects were instantiated with its previous version. A full\nrefresh is required in such cases.\n\nDue to Gleam&#39;s heavy reliance on `instanceof`, please make sure you refresh on\nany dependency change. If this arises frequently with your own code, it&#39;s best\nto configure Vite to refresh on every change.\n\nHMR will otherwise work as expected, enjoy!\n\n#### `toRefs`, `reactive` support\n\n`toRefs` and `reactive` are not easy to translate into Gleam. Research required.\n\n### Sponsored by Nestful\n\n&lt;a href=&quot;https://nestful.app&quot;&gt;\n  &lt;p align=&quot;center&quot;&gt;\n    &lt;img src=&quot;nestful.png&quot;&gt;\n  &lt;/p&gt;\n&lt;/a&gt;\n\nVleam is developed for and sponsored by [Nestful](https://nestful.app), the best\napp there is to manage your own time.\n\n### Thanks &amp; Acknowledgements\n\n- [Enderchief/gleam-tools](gleam-tools/vite-gleam)\n","url":"index.html"},{"doc":"vleam/vue","title":"App","content":"pub type App\n A Vue App\n\nSynonyms:\nvleam/vue.App\nvleam/vue App","url":"vleam/vue.html#App"},{"doc":"vleam/vue","title":"Component","content":"pub type Component\n A Vue Component\n\nSynonyms:\nvleam/vue.Component\nvleam/vue Component","url":"vleam/vue.html#Component"},{"doc":"vleam/vue","title":"ComponentBase","content":"pub type ComponentBase(required_props, nullable_props, emits)\n An incomplete component representation piped during component definition.\n See `define_component` for a full example.\n\nSynonyms:\nvleam/vue.ComponentBase\nvleam/vue ComponentBase","url":"vleam/vue.html#ComponentBase"},{"doc":"vleam/vue","title":"Computed","content":"pub type Computed(value)\n A `vue` `computed`\n\nSynonyms:\nvleam/vue.Computed\nvleam/vue Computed","url":"vleam/vue.html#Computed"},{"doc":"vleam/vue","title":"DebuggerEvent","content":"pub type DebuggerEvent\n DebuggerEvent returned from Vue\n\nSynonyms:\nvleam/vue.DebuggerEvent\nvleam/vue DebuggerEvent","url":"vleam/vue.html#DebuggerEvent"},{"doc":"vleam/vue","title":"Directive","content":"pub type Directive\n A vue directive\n\nSynonyms:\nvleam/vue.Directive\nvleam/vue Directive","url":"vleam/vue.html#Directive"},{"doc":"vleam/vue","title":"NullableProp","content":"pub type NullableProp(value) {\n  NullableProp(name: String)\n}\n NullableProp record to be used on component definition.\n See `define_component` for a full example.\nNullableProp(name: String)\n\n\nSynonyms:\nvleam/vue.NullableProp\nvleam/vue NullableProp","url":"vleam/vue.html#NullableProp"},{"doc":"vleam/vue","title":"Prop","content":"pub type Prop(value) {\n  Prop(name: String, default: Option(value))\n}\n Prop record to be used on component definition.\n See `define_component` for a full example.\nProp(name: String, default: Option(value))\n\n\nSynonyms:\nvleam/vue.Prop\nvleam/vue Prop","url":"vleam/vue.html#Prop"},{"doc":"vleam/vue","title":"Ref","content":"pub type Ref(value)\n A `vue` `ref`\n\nSynonyms:\nvleam/vue.Ref\nvleam/vue Ref","url":"vleam/vue.html#Ref"},{"doc":"vleam/vue","title":"ShallowRef","content":"pub type ShallowRef(value)\n A `vue` `shallowRef`\n\nSynonyms:\nvleam/vue.ShallowRef\nvleam/vue ShallowRef","url":"vleam/vue.html#ShallowRef"},{"doc":"vleam/vue","title":"VueError","content":"pub type VueError {\n  ComponentNotFound\n}\n\nComponentNotFound\n\n\nSynonyms:\nvleam/vue.VueError\nvleam/vue VueError","url":"vleam/vue.html#VueError"},{"doc":"vleam/vue","title":"Watchable","content":"pub type Watchable(value) {\n  Ref(watchable: Ref(value))\n  ShallowRef(watchable: ShallowRef(value))\n  Computed(watchable: Computed(value))\n  Function(watchable: fn() -&gt; value)\n  Plain(watchable: value)\n}\n Watchable types\nRef(watchable: Ref(value))\n\n\nShallowRef(watchable: ShallowRef(value))\n\n\nComputed(watchable: Computed(value))\n\n\nFunction(watchable: fn() -&gt; value)\n\n\nPlain(watchable: value)\n\n\nSynonyms:\nvleam/vue.Watchable\nvleam/vue Watchable","url":"vleam/vue.html#Watchable"},{"doc":"vleam/vue","title":"computed","content":"pub fn computed(value: fn() -&gt; a) -&gt; Computed(a)\n Define computed\nSynonyms:\nvleam/vue.computed\nvleam/vue computed","url":"vleam/vue.html#computed"},{"doc":"vleam/vue","title":"computed_value","content":"pub fn computed_value(computed: Computed(a)) -&gt; a\n Get computed value\nSynonyms:\nvleam/vue.computed_value\nvleam/vue computed_value","url":"vleam/vue.html#computed_value"},{"doc":"vleam/vue","title":"define_component","content":"pub fn define_component(\n  components components: List(#(String, fn() -&gt; Component)),\n  directives directives: List(#(String, fn() -&gt; Directive)),\n  inherit_attrs inherit_attrs: Bool,\n) -&gt; ComponentBase(Nil, Nil, Nil)\n Entrypoint for component definition. optionally piped to a\n `with_n_props` and/or `with_n_nullable_props` and/or `with_emits`\n functions, and must be finally piped to `setup`.\n\n `components` is a list of #(component_name, fn() -&gt; Component) tuples. There\n are three possible ways to gain access to components:\n\n 1. Using `@external` to refer to a component defined in Javascript\n 2. Importing a component defined in Gleam using this library\n 3. Using them without the need to refer them in `define_component`, either\n    by gloabl definition with `vue.component` or by an auto-import mechanism\n    similar to Nuxt&#39;s\n\n `directives` is a list of #(directive_name, fn() -&gt; Directive) tuples.\n\n `inherit_attrs` is a boolean, identical to Vue&#39;s javascript configuration.\n\n ## Example\n\n \n import gleam/option.{None, Some}\n import gleam/string\n import vleam/vue.{\n   type Component, NullableProp, Prop, define_component, setup,\n   with_1_nullable_prop, with_1_prop,\n }\n \n import vleam_todo/models.{type Todo, type TodoError}\n \n type InputEvent\n \n // Import the default export from HelloWorld.vue\n // This is technically an incorrect type, but it&#39;ll work. C&#39;est la vie.\n @external(javascript, &quot;/src/components/HelloWorld.vue&quot;, &quot;default&quot;)\n fn hello_world_component() -&gt; Component\n \n // Also works for external packages, although @ sign has to be aliased\n @external(javascript, &quot;heroicons/vue/24/solid&quot;, &quot;UserIcon&quot;)\n fn user_icon() -&gt; Component\n \n // or you can predefine in TS/JS\n @external(javascript, &quot;/src/ffi.ts&quot;, &quot;CheckIcon&quot;)\n fn check_icon() -&gt; #(String, fn() -&gt; Component)\n \n pub fn default_export() -&gt; Component {\n   define_component(\n     [\n       #(&quot;HelloWorld&quot;, hello_world_component),\n       #(&quot;UserIcon&quot;, user_icon),\n       check_icon(),\n     ],\n     [],\n     False,\n   )\n   |&gt; with_1_prop(\n     Prop(&quot;initialName&quot;, None),\n   )\n   |&gt; with_1_nullable_prop(\n     Prop(&quot;greeting&quot;, Some(&quot;Hello, &quot;)),\n   )\n   // Props are handed as Computed for reactivity. It&#39;s best practice to\n   // always type them, as types are only inferred if there&#39;s a default value.\n   |&gt; setup(fn(\n     required_props: #(Computed(String)),\n     nullable_props: #(Computed(String)),\n     _\n   ) {\n     let initial_name = props.0\n     let greeting = props.1\n\n     // Errors are thrown. This is just a demo, don&#39;t throw on bad input,\n     // only on irrecoverable errors.\n     use &lt;- bool.guard(\n       {\n         greeting\n         |&gt; vue.computed_value\n         |&gt; string.length\n       }\n       &gt; 0,\n       Error(&quot;Empty greeting&quot;),\n     )\n\n     let change_count = vue.shallow_ref(0)\n     let increment_count = fn() {\n       change_count\n       |&gt; vue.shallow_ref_set(vue.shallow_ref_value(change_count) + 1)\n     }\n\n     let name =\n       initial_name\n       |&gt; vue.computed_value\n       |&gt; vue.shallow_ref\n\n     let change_name = fn(new_name) {\n       name\n       |&gt; vue.shallow_ref_set(new_name)\n     }\n     let full_greeting =\n       vue.computed(fn() {\n         name\n         |&gt; vue.shallow_ref_value\n         |&gt; string.append(\n           greeting\n           |&gt; vue.computed_value\n         )\n \n         increment_count()\n       })\n\n     // To return values to the template, the FFI expects an Ok() with a\n     // tuple of object entires tuples. The following is identical to Vue&#39;s:\n     //\n     // return {\n     //   fullGreeting: full_greeting,\n     //   changeName: change_name,\n     //   changeCount: change_count,\n     // };\n     Ok(#(\n       #(&quot;fullGreeting&quot;, full_greeting),\n       #(&quot;changeName&quot;, change_name),\n       #(&quot;changeCount&quot;, change_count),\n     ))\n   })\n }\n \nSynonyms:\nvleam/vue.define_component\nvleam/vue define_component","url":"vleam/vue.html#define_component"},{"doc":"vleam/vue","title":"get_component","content":"pub fn get_component(\n  vue_app: App,\n  component_name: String,\n) -&gt; Result(Component, VueError)\n Returns components that were registered using `app.component`\nSynonyms:\nvleam/vue.get_component\nvleam/vue get_component","url":"vleam/vue.html#get_component"},{"doc":"vleam/vue","title":"inject","content":"pub fn inject(key: String) -&gt; Option(a)\n\nSynonyms:\nvleam/vue.inject\nvleam/vue inject","url":"vleam/vue.html#inject"},{"doc":"vleam/vue","title":"inject_with_default","content":"pub fn inject_with_default(key: String, default: a) -&gt; a\n\nSynonyms:\nvleam/vue.inject_with_default\nvleam/vue inject_with_default","url":"vleam/vue.html#inject_with_default"},{"doc":"vleam/vue","title":"inject_with_factory","content":"pub fn inject_with_factory(key: String, factory: fn() -&gt; a) -&gt; a\n\nSynonyms:\nvleam/vue.inject_with_factory\nvleam/vue inject_with_factory","url":"vleam/vue.html#inject_with_factory"},{"doc":"vleam/vue","title":"next_tick","content":"pub fn next_tick() -&gt; Promise(Nil)\n vue.nextTick()\n https://vuejs.org/api/general.html#nexttick\nSynonyms:\nvleam/vue.next_tick\nvleam/vue next_tick","url":"vleam/vue.html#next_tick"},{"doc":"vleam/vue","title":"next_tick_action","content":"pub fn next_tick_action(callback: fn() -&gt; Nil) -&gt; Promise(Nil)\n\nSynonyms:\nvleam/vue.next_tick_action\nvleam/vue next_tick_action","url":"vleam/vue.html#next_tick_action"},{"doc":"vleam/vue","title":"on_activated","content":"pub fn on_activated(handler: fn() -&gt; Nil) -&gt; Nil\n\nSynonyms:\nvleam/vue.on_activated\nvleam/vue on_activated","url":"vleam/vue.html#on_activated"},{"doc":"vleam/vue","title":"on_before_mount","content":"pub fn on_before_mount(handler: fn() -&gt; Nil) -&gt; Nil\n\nSynonyms:\nvleam/vue.on_before_mount\nvleam/vue on_before_mount","url":"vleam/vue.html#on_before_mount"},{"doc":"vleam/vue","title":"on_before_unmount","content":"pub fn on_before_unmount(handler: fn() -&gt; Nil) -&gt; Nil\n\nSynonyms:\nvleam/vue.on_before_unmount\nvleam/vue on_before_unmount","url":"vleam/vue.html#on_before_unmount"},{"doc":"vleam/vue","title":"on_before_update","content":"pub fn on_before_update(handler: fn() -&gt; Nil) -&gt; Nil\n\nSynonyms:\nvleam/vue.on_before_update\nvleam/vue on_before_update","url":"vleam/vue.html#on_before_update"},{"doc":"vleam/vue","title":"on_deactivated","content":"pub fn on_deactivated(handler: fn() -&gt; Nil) -&gt; Nil\n\nSynonyms:\nvleam/vue.on_deactivated\nvleam/vue on_deactivated","url":"vleam/vue.html#on_deactivated"},{"doc":"vleam/vue","title":"on_mounted","content":"pub fn on_mounted(handler: fn() -&gt; Nil) -&gt; Nil\n\nSynonyms:\nvleam/vue.on_mounted\nvleam/vue on_mounted","url":"vleam/vue.html#on_mounted"},{"doc":"vleam/vue","title":"on_unmounted","content":"pub fn on_unmounted(handler: fn() -&gt; Nil) -&gt; Nil\n\nSynonyms:\nvleam/vue.on_unmounted\nvleam/vue on_unmounted","url":"vleam/vue.html#on_unmounted"},{"doc":"vleam/vue","title":"on_updated","content":"pub fn on_updated(handler: fn() -&gt; Nil) -&gt; Nil\n\nSynonyms:\nvleam/vue.on_updated\nvleam/vue on_updated","url":"vleam/vue.html#on_updated"},{"doc":"vleam/vue","title":"provide","content":"pub fn provide(key: String, value: a) -&gt; Nil\n\nSynonyms:\nvleam/vue.provide\nvleam/vue provide","url":"vleam/vue.html#provide"},{"doc":"vleam/vue","title":"ref","content":"pub fn ref(initial_value: a) -&gt; Ref(a)\n Define a ref\nSynonyms:\nvleam/vue.ref\nvleam/vue ref","url":"vleam/vue.html#ref"},{"doc":"vleam/vue","title":"ref_set","content":"pub fn ref_set(ref: Ref(a), value: a) -&gt; Ref(a)\n Set ref value\nSynonyms:\nvleam/vue.ref_set\nvleam/vue ref_set","url":"vleam/vue.html#ref_set"},{"doc":"vleam/vue","title":"ref_value","content":"pub fn ref_value(value: Ref(a)) -&gt; a\n Get ref value\nSynonyms:\nvleam/vue.ref_value\nvleam/vue ref_value","url":"vleam/vue.html#ref_value"},{"doc":"vleam/vue","title":"register_component","content":"pub fn register_component(\n  vue_app: App,\n  component_name: String,\n  component: Component,\n) -&gt; App\n Registers components using `app.component`\nSynonyms:\nvleam/vue.register_component\nvleam/vue register_component","url":"vleam/vue.html#register_component"},{"doc":"vleam/vue","title":"setup","content":"pub fn setup(\n  base: ComponentBase(a, b, c),\n  setup: fn(a, b, c) -&gt; d,\n) -&gt; Component\n Component setup function \n See `define_component` for a full example.\nSynonyms:\nvleam/vue.setup\nvleam/vue setup","url":"vleam/vue.html#setup"},{"doc":"vleam/vue","title":"shallow_ref","content":"pub fn shallow_ref(value: a) -&gt; ShallowRef(a)\n Define a shallow ref\nSynonyms:\nvleam/vue.shallow_ref\nvleam/vue shallow_ref","url":"vleam/vue.html#shallow_ref"},{"doc":"vleam/vue","title":"shallow_ref_set","content":"pub fn shallow_ref_set(\n  ref: ShallowRef(a),\n  value: a,\n) -&gt; ShallowRef(a)\n Set shallow ref value\nSynonyms:\nvleam/vue.shallow_ref_set\nvleam/vue shallow_ref_set","url":"vleam/vue.html#shallow_ref_set"},{"doc":"vleam/vue","title":"shallow_ref_value","content":"pub fn shallow_ref_value(a: ShallowRef(a)) -&gt; a\n Get shallow ref value\nSynonyms:\nvleam/vue.shallow_ref_value\nvleam/vue shallow_ref_value","url":"vleam/vue.html#shallow_ref_value"},{"doc":"vleam/vue","title":"trigger_ref","content":"pub fn trigger_ref(ref: ShallowRef(a)) -&gt; Nil\n Trigger a shallow ref\nSynonyms:\nvleam/vue.trigger_ref\nvleam/vue trigger_ref","url":"vleam/vue.html#trigger_ref"},{"doc":"vleam/vue","title":"watch1","content":"pub fn watch1(\n  reflikes reflikes: #(Watchable(a)),\n  callback callback: fn(a, a, Option(fn(fn() -&gt; Nil) -&gt; Nil)) -&gt;\n    Nil,\n) -&gt; Nil\n\nSynonyms:\nvleam/vue.watch1\nvleam/vue watch1","url":"vleam/vue.html#watch1"},{"doc":"vleam/vue","title":"watch1_with_options","content":"pub fn watch1_with_options(\n  reflikes reflikes: #(Watchable(a)),\n  callback callback: fn(a, a, Option(fn(fn() -&gt; Nil) -&gt; Nil)) -&gt;\n    Nil,\n  immediate immediate: Option(Bool),\n  deep deep: Option(Bool),\n  flush flush: Option(String),\n  on_track on_track: Option(fn(DebuggerEvent) -&gt; Nil),\n  on_trigger on_trigger: Option(fn(DebuggerEvent) -&gt; Nil),\n  once once: Option(Bool),\n) -&gt; Nil\n\nSynonyms:\nvleam/vue.watch1_with_options\nvleam/vue watch1_with_options","url":"vleam/vue.html#watch1_with_options"},{"doc":"vleam/vue","title":"watch2","content":"pub fn watch2(\n  reflikes reflikes: #(Watchable(a), Watchable(b)),\n  callback callback: fn(\n    #(Watchable(a), Watchable(b)),\n    #(Watchable(a), Watchable(b)),\n    Option(fn(fn() -&gt; Nil) -&gt; Nil),\n  ) -&gt; Nil,\n) -&gt; Nil\n\nSynonyms:\nvleam/vue.watch2\nvleam/vue watch2","url":"vleam/vue.html#watch2"},{"doc":"vleam/vue","title":"watch2_with_options","content":"pub fn watch2_with_options(\n  reflikes reflikes: #(Watchable(a), Watchable(b)),\n  callback callback: fn(\n    #(Watchable(a), Watchable(b)),\n    #(Watchable(a), Watchable(b)),\n    Option(fn(fn() -&gt; Nil) -&gt; Nil),\n  ) -&gt; Nil,\n  immediate immediate: Option(Bool),\n  deep deep: Option(Bool),\n  flush flush: Option(String),\n  on_track on_track: Option(fn(DebuggerEvent) -&gt; Nil),\n  on_trigger on_trigger: Option(fn(DebuggerEvent) -&gt; Nil),\n  once once: Option(Bool),\n) -&gt; Nil\n\nSynonyms:\nvleam/vue.watch2_with_options\nvleam/vue watch2_with_options","url":"vleam/vue.html#watch2_with_options"},{"doc":"vleam/vue","title":"watch3","content":"pub fn watch3(\n  reflikes reflikes: #(Watchable(a), Watchable(b), Watchable(c)),\n  callback callback: fn(\n    #(Watchable(a), Watchable(b), Watchable(c)),\n    #(Watchable(a), Watchable(b), Watchable(c)),\n    Option(fn(fn() -&gt; Nil) -&gt; Nil),\n  ) -&gt; Nil,\n) -&gt; Nil\n\nSynonyms:\nvleam/vue.watch3\nvleam/vue watch3","url":"vleam/vue.html#watch3"},{"doc":"vleam/vue","title":"watch3_with_options","content":"pub fn watch3_with_options(\n  reflikes reflikes: #(Watchable(a), Watchable(b), Watchable(c)),\n  callback callback: fn(\n    #(Watchable(a), Watchable(b), Watchable(c)),\n    #(Watchable(a), Watchable(b), Watchable(c)),\n    Option(fn(fn() -&gt; Nil) -&gt; Nil),\n  ) -&gt; Nil,\n  immediate immediate: Option(Bool),\n  deep deep: Option(Bool),\n  flush flush: Option(String),\n  on_track on_track: Option(fn(DebuggerEvent) -&gt; Nil),\n  on_trigger on_trigger: Option(fn(DebuggerEvent) -&gt; Nil),\n  once once: Option(Bool),\n) -&gt; Nil\n\nSynonyms:\nvleam/vue.watch3_with_options\nvleam/vue watch3_with_options","url":"vleam/vue.html#watch3_with_options"},{"doc":"vleam/vue","title":"watch4","content":"pub fn watch4(\n  reflikes reflikes: #(\n    Watchable(a),\n    Watchable(b),\n    Watchable(c),\n    Watchable(d),\n  ),\n  callback callback: fn(\n    #(Watchable(a), Watchable(b), Watchable(c), Watchable(d)),\n    #(Watchable(a), Watchable(b), Watchable(c), Watchable(d)),\n    Option(fn(fn() -&gt; Nil) -&gt; Nil),\n  ) -&gt; Nil,\n) -&gt; Nil\n\nSynonyms:\nvleam/vue.watch4\nvleam/vue watch4","url":"vleam/vue.html#watch4"},{"doc":"vleam/vue","title":"watch4_with_options","content":"pub fn watch4_with_options(\n  reflikes reflikes: #(\n    Watchable(a),\n    Watchable(b),\n    Watchable(c),\n    Watchable(d),\n  ),\n  callback callback: fn(\n    #(Watchable(a), Watchable(b), Watchable(c), Watchable(d)),\n    #(Watchable(a), Watchable(b), Watchable(c), Watchable(d)),\n    Option(fn(fn() -&gt; Nil) -&gt; Nil),\n  ) -&gt; Nil,\n  immediate immediate: Option(Bool),\n  deep deep: Option(Bool),\n  flush flush: Option(String),\n  on_track on_track: Option(fn(DebuggerEvent) -&gt; Nil),\n  on_trigger on_trigger: Option(fn(DebuggerEvent) -&gt; Nil),\n  once once: Option(Bool),\n) -&gt; Nil\n\nSynonyms:\nvleam/vue.watch4_with_options\nvleam/vue watch4_with_options","url":"vleam/vue.html#watch4_with_options"},{"doc":"vleam/vue","title":"watch5","content":"pub fn watch5(\n  reflikes reflikes: #(\n    Watchable(a),\n    Watchable(b),\n    Watchable(c),\n    Watchable(d),\n    Watchable(e),\n  ),\n  callback callback: fn(\n    #(\n      Watchable(a),\n      Watchable(b),\n      Watchable(c),\n      Watchable(d),\n      Watchable(e),\n    ),\n    #(\n      Watchable(a),\n      Watchable(b),\n      Watchable(c),\n      Watchable(d),\n      Watchable(e),\n    ),\n    Option(fn(fn() -&gt; Nil) -&gt; Nil),\n  ) -&gt; Nil,\n) -&gt; Nil\n\nSynonyms:\nvleam/vue.watch5\nvleam/vue watch5","url":"vleam/vue.html#watch5"},{"doc":"vleam/vue","title":"watch5_with_options","content":"pub fn watch5_with_options(\n  reflikes reflikes: #(\n    Watchable(a),\n    Watchable(b),\n    Watchable(c),\n    Watchable(d),\n    Watchable(e),\n  ),\n  callback callback: fn(\n    #(\n      Watchable(a),\n      Watchable(b),\n      Watchable(c),\n      Watchable(d),\n      Watchable(e),\n    ),\n    #(\n      Watchable(a),\n      Watchable(b),\n      Watchable(c),\n      Watchable(d),\n      Watchable(e),\n    ),\n    Option(fn(fn() -&gt; Nil) -&gt; Nil),\n  ) -&gt; Nil,\n  immediate immediate: Option(Bool),\n  deep deep: Option(Bool),\n  flush flush: Option(String),\n  on_track on_track: Option(fn(DebuggerEvent) -&gt; Nil),\n  on_trigger on_trigger: Option(fn(DebuggerEvent) -&gt; Nil),\n  once once: Option(Bool),\n) -&gt; Nil\n\nSynonyms:\nvleam/vue.watch5_with_options\nvleam/vue watch5_with_options","url":"vleam/vue.html#watch5_with_options"},{"doc":"vleam/vue","title":"with_1_nullable_prop","content":"pub fn with_1_nullable_prop(\n  component: ComponentBase(a, b, c),\n  prop_1: NullableProp(d),\n) -&gt; ComponentBase(a, #(Computed(Option(d))), c)\n Define 1 prop on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_1_nullable_prop\nvleam/vue with_1_nullable_prop","url":"vleam/vue.html#with_1_nullable_prop"},{"doc":"vleam/vue","title":"with_1_prop","content":"pub fn with_1_prop(\n  component: ComponentBase(a, b, c),\n  prop_1: Prop(d),\n) -&gt; ComponentBase(#(Computed(d)), b, c)\n Define 1 prop on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_1_prop\nvleam/vue with_1_prop","url":"vleam/vue.html#with_1_prop"},{"doc":"vleam/vue","title":"with_2_nullable_props","content":"pub fn with_2_nullable_props(\n  component: ComponentBase(a, b, c),\n  prop_1: NullableProp(d),\n  prop_2: NullableProp(e),\n) -&gt; ComponentBase(\n  a,\n  #(Computed(Option(d)), Computed(Option(e))),\n  c,\n)\n Define 2 props on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_2_nullable_props\nvleam/vue with_2_nullable_props","url":"vleam/vue.html#with_2_nullable_props"},{"doc":"vleam/vue","title":"with_2_props","content":"pub fn with_2_props(\n  component: ComponentBase(a, b, c),\n  prop_1: Prop(d),\n  prop_2: Prop(e),\n) -&gt; ComponentBase(#(Computed(d), Computed(e)), b, c)\n Define 2 props on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_2_props\nvleam/vue with_2_props","url":"vleam/vue.html#with_2_props"},{"doc":"vleam/vue","title":"with_3_nullable_props","content":"pub fn with_3_nullable_props(\n  component: ComponentBase(a, b, c),\n  prop_1: NullableProp(d),\n  prop_2: NullableProp(e),\n  prop_3: NullableProp(f),\n) -&gt; ComponentBase(\n  a,\n  #(Computed(Option(d)), Computed(Option(e)), Computed(Option(f))),\n  c,\n)\n Define 3 props on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_3_nullable_props\nvleam/vue with_3_nullable_props","url":"vleam/vue.html#with_3_nullable_props"},{"doc":"vleam/vue","title":"with_3_props","content":"pub fn with_3_props(\n  component: ComponentBase(a, b, c),\n  prop_1: Prop(d),\n  prop_2: Prop(e),\n  prop_3: Prop(f),\n) -&gt; ComponentBase(#(Computed(d), Computed(e), Computed(f)), b, c)\n Define 3 props on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_3_props\nvleam/vue with_3_props","url":"vleam/vue.html#with_3_props"},{"doc":"vleam/vue","title":"with_4_nullable_props","content":"pub fn with_4_nullable_props(\n  component: ComponentBase(a, b, c),\n  prop_1: NullableProp(d),\n  prop_2: NullableProp(e),\n  prop_3: NullableProp(f),\n  prop_4: NullableProp(g),\n) -&gt; ComponentBase(\n  a,\n  #(\n    Computed(Option(d)),\n    Computed(Option(e)),\n    Computed(Option(f)),\n    Computed(Option(g)),\n  ),\n  c,\n)\n Define 4 props on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_4_nullable_props\nvleam/vue with_4_nullable_props","url":"vleam/vue.html#with_4_nullable_props"},{"doc":"vleam/vue","title":"with_4_props","content":"pub fn with_4_props(\n  component: ComponentBase(a, b, c),\n  prop_1: Prop(d),\n  prop_2: Prop(e),\n  prop_3: Prop(f),\n  prop_4: Prop(g),\n) -&gt; ComponentBase(\n  #(Computed(d), Computed(e), Computed(f), Computed(g)),\n  b,\n  c,\n)\n Define 4 props on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_4_props\nvleam/vue with_4_props","url":"vleam/vue.html#with_4_props"},{"doc":"vleam/vue","title":"with_5_nullable_props","content":"pub fn with_5_nullable_props(\n  component: ComponentBase(a, b, c),\n  prop_1: NullableProp(d),\n  prop_2: NullableProp(e),\n  prop_3: NullableProp(f),\n  prop_4: NullableProp(g),\n  prop_5: NullableProp(h),\n) -&gt; ComponentBase(\n  a,\n  #(\n    Computed(Option(d)),\n    Computed(Option(e)),\n    Computed(Option(f)),\n    Computed(Option(g)),\n    Computed(Option(h)),\n  ),\n  c,\n)\n Define 5 props on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_5_nullable_props\nvleam/vue with_5_nullable_props","url":"vleam/vue.html#with_5_nullable_props"},{"doc":"vleam/vue","title":"with_5_props","content":"pub fn with_5_props(\n  component: ComponentBase(a, b, c),\n  prop_1: Prop(d),\n  prop_2: Prop(e),\n  prop_3: Prop(f),\n  prop_4: Prop(g),\n  prop_5: Prop(h),\n) -&gt; ComponentBase(\n  #(\n    Computed(d),\n    Computed(e),\n    Computed(f),\n    Computed(g),\n    Computed(h),\n  ),\n  b,\n  c,\n)\n Define 5 props on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_5_props\nvleam/vue with_5_props","url":"vleam/vue.html#with_5_props"},{"doc":"vleam/vue","title":"with_6_nullable_props","content":"pub fn with_6_nullable_props(\n  component: ComponentBase(a, b, c),\n  prop_1: NullableProp(d),\n  prop_2: NullableProp(e),\n  prop_3: NullableProp(f),\n  prop_4: NullableProp(g),\n  prop_5: NullableProp(h),\n  prop_6: NullableProp(i),\n) -&gt; ComponentBase(\n  a,\n  #(\n    Computed(Option(d)),\n    Computed(Option(e)),\n    Computed(Option(f)),\n    Computed(Option(g)),\n    Computed(Option(h)),\n    Computed(Option(i)),\n  ),\n  c,\n)\n Define 6 props on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_6_nullable_props\nvleam/vue with_6_nullable_props","url":"vleam/vue.html#with_6_nullable_props"},{"doc":"vleam/vue","title":"with_6_props","content":"pub fn with_6_props(\n  component: ComponentBase(a, b, c),\n  prop_1: Prop(d),\n  prop_2: Prop(e),\n  prop_3: Prop(f),\n  prop_4: Prop(g),\n  prop_5: Prop(h),\n  prop_6: Prop(i),\n) -&gt; ComponentBase(\n  #(\n    Computed(d),\n    Computed(e),\n    Computed(f),\n    Computed(g),\n    Computed(h),\n    Computed(i),\n  ),\n  b,\n  c,\n)\n Define 6 props on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_6_props\nvleam/vue with_6_props","url":"vleam/vue.html#with_6_props"},{"doc":"vleam/vue","title":"with_7_nullable_props","content":"pub fn with_7_nullable_props(\n  component: ComponentBase(a, b, c),\n  prop_1: NullableProp(d),\n  prop_2: NullableProp(e),\n  prop_3: NullableProp(f),\n  prop_4: NullableProp(g),\n  prop_5: NullableProp(h),\n  prop_6: NullableProp(i),\n  prop_7: NullableProp(j),\n) -&gt; ComponentBase(\n  a,\n  #(\n    Computed(Option(d)),\n    Computed(Option(e)),\n    Computed(Option(f)),\n    Computed(Option(g)),\n    Computed(Option(h)),\n    Computed(Option(i)),\n    Computed(Option(j)),\n  ),\n  c,\n)\n Define 7 props on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_7_nullable_props\nvleam/vue with_7_nullable_props","url":"vleam/vue.html#with_7_nullable_props"},{"doc":"vleam/vue","title":"with_7_props","content":"pub fn with_7_props(\n  component: ComponentBase(a, b, c),\n  prop_1: Prop(d),\n  prop_2: Prop(e),\n  prop_3: Prop(f),\n  prop_4: Prop(g),\n  prop_5: Prop(h),\n  prop_6: Prop(i),\n  prop_7: Prop(j),\n) -&gt; ComponentBase(\n  #(\n    Computed(d),\n    Computed(e),\n    Computed(f),\n    Computed(g),\n    Computed(h),\n    Computed(i),\n    Computed(j),\n  ),\n  b,\n  c,\n)\n Define 7 props on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_7_props\nvleam/vue with_7_props","url":"vleam/vue.html#with_7_props"},{"doc":"vleam/vue","title":"with_8_nullable_props","content":"pub fn with_8_nullable_props(\n  component: ComponentBase(a, b, c),\n  prop_1: NullableProp(d),\n  prop_2: NullableProp(e),\n  prop_3: NullableProp(f),\n  prop_4: NullableProp(g),\n  prop_5: NullableProp(h),\n  prop_6: NullableProp(i),\n  prop_7: NullableProp(j),\n  prop_8: NullableProp(k),\n) -&gt; ComponentBase(\n  a,\n  #(\n    Computed(Option(d)),\n    Computed(Option(e)),\n    Computed(Option(f)),\n    Computed(Option(g)),\n    Computed(Option(h)),\n    Computed(Option(i)),\n    Computed(Option(j)),\n    Computed(Option(k)),\n  ),\n  c,\n)\n Define 8 props on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_8_nullable_props\nvleam/vue with_8_nullable_props","url":"vleam/vue.html#with_8_nullable_props"},{"doc":"vleam/vue","title":"with_8_props","content":"pub fn with_8_props(\n  component: ComponentBase(a, b, c),\n  prop_1: Prop(d),\n  prop_2: Prop(e),\n  prop_3: Prop(f),\n  prop_4: Prop(g),\n  prop_5: Prop(h),\n  prop_6: Prop(i),\n  prop_7: Prop(j),\n  prop_8: Prop(k),\n) -&gt; ComponentBase(\n  #(\n    Computed(d),\n    Computed(e),\n    Computed(f),\n    Computed(g),\n    Computed(h),\n    Computed(i),\n    Computed(j),\n    Computed(k),\n  ),\n  b,\n  c,\n)\n Define 8 props on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_8_props\nvleam/vue with_8_props","url":"vleam/vue.html#with_8_props"},{"doc":"vleam/vue","title":"with_9_nullable_props","content":"pub fn with_9_nullable_props(\n  component: ComponentBase(a, b, c),\n  prop_1: NullableProp(d),\n  prop_2: NullableProp(e),\n  prop_3: NullableProp(f),\n  prop_4: NullableProp(g),\n  prop_5: NullableProp(h),\n  prop_6: NullableProp(i),\n  prop_7: NullableProp(j),\n  prop_8: NullableProp(k),\n  prop_9: NullableProp(l),\n) -&gt; ComponentBase(\n  a,\n  #(\n    Computed(Option(d)),\n    Computed(Option(e)),\n    Computed(Option(f)),\n    Computed(Option(g)),\n    Computed(Option(h)),\n    Computed(Option(i)),\n    Computed(Option(j)),\n    Computed(Option(k)),\n    Computed(Option(l)),\n  ),\n  c,\n)\n Define 9 props on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_9_nullable_props\nvleam/vue with_9_nullable_props","url":"vleam/vue.html#with_9_nullable_props"},{"doc":"vleam/vue","title":"with_9_props","content":"pub fn with_9_props(\n  component: ComponentBase(a, b, c),\n  prop_1: Prop(d),\n  prop_2: Prop(e),\n  prop_3: Prop(f),\n  prop_4: Prop(g),\n  prop_5: Prop(h),\n  prop_6: Prop(i),\n  prop_7: Prop(j),\n  prop_8: Prop(k),\n  prop_9: Prop(l),\n) -&gt; ComponentBase(\n  #(\n    Computed(d),\n    Computed(e),\n    Computed(f),\n    Computed(g),\n    Computed(h),\n    Computed(i),\n    Computed(j),\n    Computed(k),\n    Computed(l),\n  ),\n  b,\n  c,\n)\n Define 9 props on a component\n See `define_component` for a full example.\nSynonyms:\nvleam/vue.with_9_props\nvleam/vue with_9_props","url":"vleam/vue.html#with_9_props"},{"doc":"vleam/vue","title":"with_emits","content":"pub fn with_emits(\n  base: ComponentBase(a, b, c),\n  emits: List(String),\n) -&gt; ComponentBase(a, d, e)\n Define emits on a component\nSynonyms:\nvleam/vue.with_emits\nvleam/vue with_emits","url":"vleam/vue.html#with_emits"},{"doc":"vleam/vue","title":"vleam/vue","content":"","url":"vleam/vue.html"},{"doc":"vleam/vue_router","title":"RouteLocationNormalizedLoaded","content":"pub type RouteLocationNormalizedLoaded\n\n\nSynonyms:\nvleam/vue_router.RouteLocationNormalizedLoaded\nvleam/vue_router RouteLocationNormalizedLoaded","url":"vleam/vue_router.html#RouteLocationNormalizedLoaded"},{"doc":"vleam/vue_router","title":"Router","content":"pub type Router\n\n\nSynonyms:\nvleam/vue_router.Router\nvleam/vue_router Router","url":"vleam/vue_router.html#Router"},{"doc":"vleam/vue_router","title":"back","content":"pub fn back(router: Router) -&gt; Nil\n\nSynonyms:\nvleam/vue_router.back\nvleam/vue_router back","url":"vleam/vue_router.html#back"},{"doc":"vleam/vue_router","title":"current_route","content":"pub fn current_route(\n  router: Router,\n) -&gt; RouteLocationNormalizedLoaded\n\nSynonyms:\nvleam/vue_router.current_route\nvleam/vue_router current_route","url":"vleam/vue_router.html#current_route"},{"doc":"vleam/vue_router","title":"forward","content":"pub fn forward(router: Router) -&gt; Nil\n\nSynonyms:\nvleam/vue_router.forward\nvleam/vue_router forward","url":"vleam/vue_router.html#forward"},{"doc":"vleam/vue_router","title":"full_path","content":"pub fn full_path(route: RouteLocationNormalizedLoaded) -&gt; String\n\nSynonyms:\nvleam/vue_router.full_path\nvleam/vue_router full_path","url":"vleam/vue_router.html#full_path"},{"doc":"vleam/vue_router","title":"go","content":"pub fn go(router: Router, delta: Int) -&gt; Nil\n\nSynonyms:\nvleam/vue_router.go\nvleam/vue_router go","url":"vleam/vue_router.html#go"},{"doc":"vleam/vue_router","title":"hash","content":"pub fn hash(route: RouteLocationNormalizedLoaded) -&gt; String\n\nSynonyms:\nvleam/vue_router.hash\nvleam/vue_router hash","url":"vleam/vue_router.html#hash"},{"doc":"vleam/vue_router","title":"listening","content":"pub fn listening(router: Router) -&gt; Bool\n\nSynonyms:\nvleam/vue_router.listening\nvleam/vue_router listening","url":"vleam/vue_router.html#listening"},{"doc":"vleam/vue_router","title":"params","content":"pub fn params(\n  route: RouteLocationNormalizedLoaded,\n) -&gt; Dict(String, String)\n\nSynonyms:\nvleam/vue_router.params\nvleam/vue_router params","url":"vleam/vue_router.html#params"},{"doc":"vleam/vue_router","title":"path","content":"pub fn path(route: RouteLocationNormalizedLoaded) -&gt; String\n\nSynonyms:\nvleam/vue_router.path\nvleam/vue_router path","url":"vleam/vue_router.html#path"},{"doc":"vleam/vue_router","title":"push","content":"pub fn push(router: Router, to: String) -&gt; Nil\n\nSynonyms:\nvleam/vue_router.push\nvleam/vue_router push","url":"vleam/vue_router.html#push"},{"doc":"vleam/vue_router","title":"query","content":"pub fn query(\n  route: RouteLocationNormalizedLoaded,\n) -&gt; Dict(String, Option(String))\n\nSynonyms:\nvleam/vue_router.query\nvleam/vue_router query","url":"vleam/vue_router.html#query"},{"doc":"vleam/vue_router","title":"replace","content":"pub fn replace(router: Router, to: String) -&gt; Nil\n\nSynonyms:\nvleam/vue_router.replace\nvleam/vue_router replace","url":"vleam/vue_router.html#replace"},{"doc":"vleam/vue_router","title":"use_route","content":"pub fn use_route() -&gt; RouteLocationNormalizedLoaded\n\nSynonyms:\nvleam/vue_router.use_route\nvleam/vue_router use_route","url":"vleam/vue_router.html#use_route"},{"doc":"vleam/vue_router","title":"use_router","content":"pub fn use_router() -&gt; Router\n\nSynonyms:\nvleam/vue_router.use_router\nvleam/vue_router use_router","url":"vleam/vue_router.html#use_router"},{"doc":"vleam/vue_router","title":"vleam/vue_router","content":"","url":"vleam/vue_router.html"}]);